@@ -227,7 +227,7 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.5'
+    version = '1.7'
     description = '`acpi` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -333,16 +333,19 @@ def parse(data, raw=False, quiet=False):
             if obj_type == 'Battery':
                 output_line['type'] = obj_type
                 output_line['id'] = obj_id
-                if 'Charging' in line or 'Discharging' in line or 'Full' in line:
+                if 'Not charging' in line:
+                    output_line['state'] = 'Not charging'
+                    output_line['charge_percent'] = line.split()[-1].rstrip('%,')
+
+                if any(word in line for word in ('Charging', 'Discharging', 'Full')):
                     output_line['state'] = line.split()[2][:-1]
                     output_line['charge_percent'] = line.split()[3].rstrip('%,')
-                    if 'will never fully discharge' in line:
+                    if 'will never fully discharge' in line or 'rate information unavailable' in line:
                         pass
-                    elif 'rate information unavailable' not in line:
-                        if 'Charging' in line:
-                            output_line['until_charged'] = line.split()[4]
-                        if 'Discharging' in line:
-                            output_line['charge_remaining'] = line.split()[4]
+                    elif 'Charging' in line:
+                        output_line['until_charged'] = line.split()[4]
+                    elif 'Discharging' in line:
+                        output_line['charge_remaining'] = line.split()[4]
 
                 if 'design capacity' in line:
                     output_line['design_capacity_mah'] = line.split()[4]
@@ -352,10 +355,7 @@ def parse(data, raw=False, quiet=False):
             if obj_type == 'Adapter':
                 output_line['type'] = obj_type
                 output_line['id'] = obj_id
-                if 'on-line' in line:
-                    output_line['on-line'] = True
-                else:
-                    output_line['on-line'] = False
+                output_line['on-line'] = 'on-line' in line
 
             if obj_type == 'Thermal':
                 output_line['type'] = obj_type
