@@ -27,7 +27,6 @@ Schema:
       ],
       "schedule": [
         {
-          "occurrence"        string,
           "minute": [
                               string
           ],
@@ -174,7 +173,7 @@ import jc.parsers.universal
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.7'
+    version = '1.9'
     description = '`crontab` command and file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -198,7 +197,7 @@ def _process(proc_data):
 
         Dictionary. Structured data to conform to the schema.
     """
-    # put itmes in lists
+    # put items in lists
     try:
         for entry in proc_data['schedule']:
             entry['minute'] = entry['minute'].split(',')
@@ -245,7 +244,11 @@ def parse(data, raw=False, quiet=False):
         # Pop any variable assignment lines
         cron_var = []
         for i, line in reversed(list(enumerate(cleandata))):
-            if '=' in line and not line.strip()[0].isdigit() and not line.strip()[0] == '@':
+            if '=' in line \
+                and not line.strip()[0].isdigit() \
+                and not line.strip()[0] == '@' \
+                and not line.strip()[0] == '*':
+
                 var_line = cleandata.pop(i)
                 var_name = var_line.split('=', maxsplit=1)[0].strip()
                 var_value = var_line.split('=', maxsplit=1)[1].strip()
