@@ -9,11 +9,6 @@ Usage (module):
     import jc
     result = jc.parse('gshadow', gshadow_file_output)
 
-    or
-
-    import jc.parsers.gshadow
-    result = jc.parsers.gshadow.parse(gshadow_file_output)
-
 Schema:
 
     [
@@ -87,6 +82,7 @@ class info():
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux', 'aix', 'freebsd']
+    tags = ['file']
 
 
 __version__ = info.version
