@@ -14,7 +14,7 @@ Usage (cli):
 
     $ md5sum file.txt | jc --hashsum
 
-    or
+or
 
     $ jc md5sum file.txt
 
@@ -23,11 +23,6 @@ Usage (module):
     import jc
     result = jc.parse('hashsum', md5sum_command_output)
 
-    or
-
-    import jc.parsers.hashsum
-    result = jc.parsers.hashsum.parse(md5sum_command_output)
-
 Schema:
 
     [
@@ -81,6 +76,7 @@ class info():
     compatible = ['linux', 'darwin', 'cygwin', 'aix', 'freebsd']
     magic_commands = ['md5sum', 'md5', 'shasum', 'sha1sum', 'sha224sum',
                       'sha256sum', 'sha384sum', 'sha512sum']
+    tags = ['command']
 
 
 __version__ = info.version
