@@ -25,7 +25,7 @@ Schema:
             "num"               integer,
             "pkts":             integer,
             "bytes":            integer,  # converted based on suffix
-            "target":           string,
+            "target":           string,   # Null if blank
             "prot":             string,
             "opt":              string,   # "--" = Null
             "in":               string,
@@ -163,12 +163,13 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.8'
+    version = '1.10'
     description = '`iptables` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux']
     magic_commands = ['iptables']
+    tags = ['command']
 
 
 __version__ = info.version
@@ -194,33 +195,16 @@ def _process(proc_data):
                     rule[key] = jc.utils.convert_to_int(rule[key])
 
             if 'bytes' in rule:
-                multiplier = 1
-                if rule['bytes'][-1] == 'K':
-                    multiplier = 10 ** 3
-                    rule['bytes'] = rule['bytes'].rstrip('K')
-                elif rule['bytes'][-1] == 'M':
-                    multiplier = 10 ** 6
-                    rule['bytes'] = rule['bytes'].rstrip('M')
-                elif rule['bytes'][-1] == 'G':
-                    multiplier = 10 ** 9
-                    rule['bytes'] = rule['bytes'].rstrip('G')
-                elif rule['bytes'][-1] == 'T':
-                    multiplier = 10 ** 12
-                    rule['bytes'] = rule['bytes'].rstrip('T')
-                elif rule['bytes'][-1] == 'P':
-                    multiplier = 10 ** 15
-                    rule['bytes'] = rule['bytes'].rstrip('P')
-
-                try:
-                    bytes_int = jc.utils.convert_to_int(rule['bytes'])
-                    rule['bytes'] = bytes_int * multiplier
-                except (ValueError):
-                    rule['bytes'] = None
+                rule['bytes'] = jc.utils.convert_size_to_int(rule['bytes'])
 
             if 'opt' in rule:
                 if rule['opt'] == '--':
                     rule['opt'] = None
 
+            if 'target' in rule:
+                if rule['target'] == '':
+                    rule['target'] = None
+
     return proc_data
 
 
@@ -270,15 +254,18 @@ def parse(data, raw=False, quiet=False):
                 continue
 
             else:
+                # sometimes the "target" column is blank. Stuff in a dummy character
+                if headers[0] == 'target' and line.startswith(' '):
+                    line = '\u2063' + line
+
                 rule = line.split(maxsplit=len(headers) - 1)
                 temp_rule = dict(zip(headers, rule))
                 if temp_rule:
+                    if temp_rule.get('target') == '\u2063':
+                        temp_rule['target'] = ''
                     chain['rules'].append(temp_rule)
 
         if chain:
             raw_output.append(chain)
 
-    if raw:
-        return raw_output
-    else:
-        return _process(raw_output)
+    return raw_output if raw else _process(raw_output)
