@@ -21,8 +21,8 @@ Usage (module):
 
 Schema:
 
-key/value document converted to a dictionary - see the configparser standard
-library documentation for more details.
+Key/Value document converted to a dictionary - see the python configparser
+standard library documentation for more details.
 
     {
       "key1":       string,
@@ -36,6 +36,7 @@ Examples:
     name = John Doe
     address=555 California Drive
     age: 34
+
     ; comments can include # or ;
     # delimiter can be = or :
     # quoted values have quotation marks stripped by default
@@ -50,15 +51,16 @@ Examples:
       "occupation": "Engineer"
     }
 """
+import jc.parsers.ini as ini
 
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.2'
+    version = '2.1'
     description = 'Key/Value file and string parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
-    details = 'This is a wrapper for the INI parser'
+    details = 'Using the ini parser'
     compatible = ['linux', 'darwin', 'cygwin', 'win32', 'aix', 'freebsd']
     tags = ['generic', 'file', 'string']
 
@@ -70,8 +72,6 @@ def parse(data, raw=False, quiet=False):
     """
     Main text parsing function
 
-        Note: this is just a wrapper for jc.parsers.ini
-
     Parameters:
 
         data:        (string)  text data to parse
@@ -80,7 +80,8 @@ def parse(data, raw=False, quiet=False):
 
     Returns:
 
-        Dictionary representing the key/value file
+        Dictionary representing a Key/Value pair document.
     """
-    import jc.parsers.ini
-    return jc.parsers.ini.parse(data, raw=raw, quiet=quiet)
+    # This parser is an alias of ini.py
+    ini.info = info  # type: ignore
+    return ini.parse(data, raw, quiet)
