@@ -4,7 +4,7 @@ Usage (cli):
 
     $ lsblk | jc --lsblk
 
-    or
+or
 
     $ jc lsblk
 
@@ -275,12 +275,13 @@ import jc.parsers.universal
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.8'
+    version = '1.9'
     description = '`lsblk` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux']
     magic_commands = ['lsblk']
+    tags = ['command']
 
 
 __version__ = info.version
@@ -298,14 +299,16 @@ def _process(proc_data):
 
         List of Dictionaries. Structured data to conform to the schema.
     """
+    bool_list = {'rm', 'ro', 'rota', 'disc_zero', 'rand'}
+
+    int_list = {'ra', 'alignment', 'min_io', 'opt_io', 'phy_sec', 'log_sec',
+                'rq_size', 'disc_aln'}
+
     for entry in proc_data:
-        # boolean and integer changes
-        bool_list = ['rm', 'ro', 'rota', 'disc_zero', 'rand']
-        int_list = ['ra', 'alignment', 'min_io', 'opt_io', 'phy_sec', 'log_sec',
-                    'rq_size', 'disc_aln']
         for key in entry:
             if key in bool_list:
                 entry[key] = jc.utils.convert_to_bool(entry[key])
+
             if key in int_list:
                 entry[key] = jc.utils.convert_to_int(entry[key])
 
