@@ -124,8 +124,9 @@ class info():
     description = '`lsof` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
-    compatible = ['linux']
+    compatible = ['linux', 'darwin', 'aix', 'freebsd']
     magic_commands = ['lsof']
+    tags = ['command']
 
 
 __version__ = info.version
