@@ -2,6 +2,8 @@
 
 This parser conforms to the specification at https://semver.org/
 
+See Also: `ver` parser.
+
 Usage (cli):
 
     $ echo 1.2.3-rc.1+44837 | jc --semver
@@ -52,12 +54,12 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.0'
+    version = '1.1'
     description = 'Semantic Version string parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux', 'darwin', 'cygwin', 'win32', 'aix', 'freebsd']
-    tags = ['standard', 'string']
+    tags = ['standard', 'string', 'slurpable']
 
 
 __version__ = info.version
