@@ -11,7 +11,7 @@ Usage (cli):
 
     $ top -b -n 3 | jc --top
 
-    or
+or
 
     $ jc top -b -n 3
 
@@ -308,7 +308,7 @@ Examples:
       }
     ]
 """
-from typing import List, Dict
+from typing import List, Dict, Set
 import jc.utils
 from jc.parsers.uptime import parse as parse_uptime
 from jc.parsers.universal import sparse_table_parse as parse_table
@@ -316,12 +316,13 @@ from jc.parsers.universal import sparse_table_parse as parse_table
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.0'
+    version = '1.1'
     description = '`top -b` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux']
     magic_commands = ['top -b']
+    tags = ['command']
 
 
 __version__ = info.version
@@ -420,7 +421,7 @@ def _process(proc_data: List[Dict], quiet=False) -> List[Dict]:
         'Z': 'zombie'
     }
 
-    int_list: List = [
+    int_list: Set = {
         'uptime', 'users', 'tasks_total', 'tasks_running', 'tasks_sleeping', 'tasks_stopped',
         'tasks_zombie', 'pid', 'priority', 'nice', 'parent_pid', 'uid', 'real_uid', 'saved_uid',
         'gid', 'pgrp', 'tty_process_gid', 'session_id', 'thread_count', 'last_used_processor',
@@ -430,14 +431,14 @@ def _process(proc_data: List[Dict], quiet=False) -> List[Dict]:
         'user_namespace_inode', 'nts_namespace_inode', 'numa_node', 'out_of_mem_adjustment',
         'out_of_mem_score', 'resident_anon_mem', 'resident_file_backed_mem', 'resident_locked_mem',
         'resident_shared_mem'
-    ]
+    }
 
-    float_list: List = [
+    float_list: Set = {
         'load_1m', 'load_5m', 'load_15m', 'cpu_user', 'cpu_sys', 'cpu_nice', 'cpu_idle', 'cpu_wait',
         'cpu_hardware', 'cpu_software', 'cpu_steal', 'percent_cpu', 'percent_mem', 'mem_total',
         'mem_free', 'mem_used', 'mem_buff_cache', 'swap_total', 'swap_free', 'swap_used',
         'mem_available', 'virtual_mem', 'resident_mem', 'shared_mem', 'swap', 'code', 'data', 'used'
-    ]
+    }
 
     for idx, item in enumerate(proc_data):
         for key in item:
