@@ -27,6 +27,7 @@ Schema:
         "tbs_certificate": {
           "version":                      string,
           "serial_number":                string,  # [0]
+          "serial_number_str":            string,
           "signature": {
             "algorithm":                  string,
             "parameters":                 string/null,
@@ -38,7 +39,9 @@ Schema:
             "organization_name":          array/string,
             "organizational_unit_name":   array/string,
             "common_name":                string,
-            "email_address":              string
+            "email_address":              string,
+            "serial_number":              string,   # [0]
+            "serial_number_str":          string
           },
           "validity": {
             "not_before":                 integer,  # [1]
@@ -53,7 +56,9 @@ Schema:
             "organization_name":          array/string,
             "organizational_unit_name":   array/string,
             "common_name":                string,
-            "email_address":              string
+            "email_address":              string,
+            "serial_number":              string,   # [0]
+            "serial_number_str":          string
           },
           "subject_public_key_info": {
             "algorithm": {
@@ -150,7 +155,7 @@ Schema:
           ]
         }
 
-        Signed Certificate Timestamp List
+        Signed Certificate Timestamp List:
         {
           "extn_id":                    "signed_certificate_timestamp_list",
           "critical":                   boolean,
@@ -403,17 +408,18 @@ from collections import OrderedDict
 from datetime import datetime
 from typing import List, Dict, Union
 import jc.utils
-from jc.parsers.asn1crypto import pem, x509
+from jc.parsers.asn1crypto import pem, x509, jc_global
 
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.0'
+    version = '1.3'
     description = 'X.509 PEM and DER certificate file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     details = 'Using the asn1crypto library at https://github.com/wbond/asn1crypto/releases/tag/1.5.1'
     compatible = ['linux', 'darwin', 'cygwin', 'win32', 'aix', 'freebsd']
+    tags = ['standard', 'file', 'string', 'binary']
 
 
 __version__ = info.version
@@ -441,7 +447,7 @@ def _i2b(integer: int) -> bytes:
 
 def _b2a(byte_string: bytes) -> str:
     """Convert a byte string to a colon-delimited hex ascii string"""
-    # need try/except since seperator was only introduced in python 3.8.
+    # need try/except since separator was only introduced in python 3.8.
     # provides compatibility for python 3.6 and 3.7.
     try:
       return binascii.hexlify(byte_string, ':').decode('utf-8')
@@ -456,6 +462,9 @@ def _fix_objects(obj):
     Recursively traverse the nested dictionary or list and convert objects
     into JSON serializable types.
     """
+    if isinstance(obj, tuple):
+        obj = list(obj)
+
     if isinstance(obj, set):
         obj = sorted(list(obj))
 
@@ -465,7 +474,22 @@ def _fix_objects(obj):
     if isinstance(obj, dict):
         for k, v in obj.copy().items():
             if k == 'serial_number':
-                obj.update({k: _b2a(_i2b(v))})
+                # according to the spec this field can be string or integer
+                if isinstance(v, int):
+                    v_str = str(v)
+                    if v < 0:
+                        v_hex = "(Negative)" + _b2a(_i2b(abs(v)))
+                    else:
+                        v_hex = _b2a(_i2b(v))
+                else:
+                    v_str = str(v)
+                    v_hex = _b2a(v_str.encode())
+                obj.update(
+                    {
+                        k: v_hex,
+                        f'{k}_str': v_str
+                    }
+                )
                 continue
 
             if k == 'modulus':
@@ -483,6 +507,10 @@ def _fix_objects(obj):
                 obj.update({k: v})
                 continue
 
+            if isinstance(v, tuple):
+                v = list(v)
+                obj.update({k: v})
+
             if isinstance(v, set):
                 v = sorted(list(v))
                 obj.update({k: v})
@@ -496,7 +524,7 @@ def _fix_objects(obj):
                 continue
 
             if isinstance(v, list):
-                newlist =[]
+                newlist = []
                 for i in v:
                     newlist.append(_fix_objects(i))
                 obj.update({k: newlist})
@@ -530,6 +558,7 @@ def parse(
         List of Dictionaries. Raw or processed structured data.
     """
     jc.utils.compatibility(__name__, info.compatible, quiet)
+    jc_global.quiet = quiet  # to inject quiet setting into asn1crypto library
 
     raw_output: List = []
 
