@@ -24,6 +24,12 @@ class MyTests(unittest.TestCase):
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-18.04/acpi-V.out'), 'r', encoding='utf-8') as f:
         ubuntu_18_04_acpi_V = f.read()
 
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/generic/acpi-V-never-fully-discharge.out'), 'r', encoding='utf-8') as f:
+        acpi_V_never_fully_discharge = f.read()
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/generic/acpi-not-charging.out'), 'r', encoding='utf-8') as f:
+        acpi_not_charging = f.read()
+
     # output
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/generic/acpi-V.json'), 'r', encoding='utf-8') as f:
         generic_acpi_V_json = json.loads(f.read())
@@ -40,6 +46,12 @@ class MyTests(unittest.TestCase):
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-18.04/acpi-V.json'), 'r', encoding='utf-8') as f:
         ubuntu_18_04_acpi_V_json = json.loads(f.read())
 
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/generic/acpi-V-never-fully-discharge.json'), 'r', encoding='utf-8') as f:
+        acpi_V_never_fully_discharge_json = json.loads(f.read())
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/generic/acpi-not-charging.json'), 'r', encoding='utf-8') as f:
+        acpi_not_charging_json = json.loads(f.read())
+
     def test_acpi_nodata(self):
         """
         Test 'acpi' with no data
@@ -76,6 +88,18 @@ class MyTests(unittest.TestCase):
         """
         self.assertEqual(jc.parsers.acpi.parse(self.ubuntu_18_04_acpi_V, quiet=True), self.ubuntu_18_04_acpi_V_json)
 
+    def test_acpi_V_never_fully_discharge(self):
+        """
+        Test 'acpi -V' with "never fully discharge" message
+        """
+        self.assertEqual(jc.parsers.acpi.parse(self.acpi_V_never_fully_discharge, quiet=True), self.acpi_V_never_fully_discharge_json)
+
+    def test_acpi_not_charging(self):
+        """
+        Test 'acpi' with "Not charging" message
+        """
+        self.assertEqual(jc.parsers.acpi.parse(self.acpi_not_charging, quiet=True), self.acpi_not_charging_json)
+
 
 if __name__ == '__main__':
     unittest.main()
