@@ -55,7 +55,10 @@ class MyTests(unittest.TestCase):
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/ping-ip-O-unparsedlines.out'), 'r', encoding='utf-8') as f:
         centos_7_7_ping_ip_O_unparsedlines = f.read()
 
-    # ubuntu
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/ping-missing-hostname.out'), 'r', encoding='utf-8') as f:
+        centos_7_7_ping_missing_hostname = f.read()
+
+    # ubuntu 18.4
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-18.04/ping-ip-O.out'), 'r', encoding='utf-8') as f:
         ubuntu_18_4_ping_ip_O = f.read()
 
@@ -83,6 +86,22 @@ class MyTests(unittest.TestCase):
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-18.04/ping6-hostname-O-D-p-s.out'), 'r', encoding='utf-8') as f:
         ubuntu_18_4_ping6_hostname_O_D_p_s = f.read()
 
+    # ubuntu 22.4
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping-dest-unreachable.out'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping_dest_unreachable = f.read()
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping-ip-source-ip.out'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping_ip_source_ip = f.read()
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping-hostname-source-ip.out'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping_hostname_source_ip = f.read()
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping6-ip-source-ip.out'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping6_ip_source_ip = f.read()
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping6-hostname-source-ip.out'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping6_hostname_source_ip = f.read()
+
     # fedora
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/fedora32/ping-ip-O.out'), 'r', encoding='utf-8') as f:
         fedora32_ping_ip_O = f.read()
@@ -246,7 +265,10 @@ class MyTests(unittest.TestCase):
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/ping6-ip-dup-streaming.json'), 'r', encoding='utf-8') as f:
         centos_7_7_ping6_ip_dup_streaming_json = json.loads(f.read())
 
-    # ubunutu
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/ping-missing-hostname-streaming.json'), 'r', encoding='utf-8') as f:
+        centos_7_7_ping_missing_hostname_json = json.loads(f.read())
+
+    # ubunutu 18.4
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-18.04/ping-ip-O-streaming.json'), 'r', encoding='utf-8') as f:
         ubuntu_18_4_ping_ip_O_streaming_json = json.loads(f.read())
 
@@ -274,6 +296,22 @@ class MyTests(unittest.TestCase):
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-18.04/ping6-hostname-O-D-p-s-streaming.json'), 'r', encoding='utf-8') as f:
         ubuntu_18_4_ping6_hostname_O_D_p_s_streaming_json = json.loads(f.read())
 
+    # ubuntu 22.4
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping-dest-unreachable-streaming.json'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping_dest_unreachable_streaming_json = json.loads(f.read())
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping-hostname-source-ip-streaming.json'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping_hostname_I_streaming_json = json.loads(f.read())
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping-ip-source-ip-streaming.json'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping_ip_I_streaming_json = json.loads(f.read())
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping6-ip-source-ip-streaming.json'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping6_ip_I_streaming_json = json.loads(f.read())
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping6-hostname-source-ip-streaming.json'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping6_hostname_I_streaming_json = json.loads(f.read())
+
     # fedora
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/fedora32/ping-ip-O-streaming.json'), 'r', encoding='utf-8') as f:
         fedora32_ping_ip_O_streaming_json = json.loads(f.read())
@@ -555,6 +593,38 @@ class MyTests(unittest.TestCase):
         """
         self.assertEqual(list(jc.parsers.ping_s.parse(self.ubuntu_18_4_ping6_hostname_O_D_p_s.splitlines(), quiet=True)), self.ubuntu_18_4_ping6_hostname_O_D_p_s_streaming_json)
 
+    def test_ping_s_dest_unreachable_ubuntu_22_4(self):
+        """
+        Test 'ping' on Ubuntu 22.4 with destination unreachable message
+        """
+        self.assertEqual(list(jc.parsers.ping_s.parse(self.ubuntu_22_4_ping_dest_unreachable.splitlines(), quiet=True)), [self.ubuntu_22_4_ping_dest_unreachable_streaming_json])
+
+
+    def test_ping_s_hostname_I_ubuntu_22_4(self):
+        """
+        Test 'ping <hostname> -I' on ubuntu 22.04
+        """
+        self.assertEqual(list(jc.parsers.ping_s.parse(self.ubuntu_22_4_ping_hostname_source_ip.splitlines(), quiet=True)), self.ubuntu_22_4_ping_hostname_I_streaming_json)
+
+    def test_ping_s_ip_I_ubuntu_22_4(self):
+        """
+        Test 'ping <ip> -I' on ubuntu 22.04
+        """
+        self.assertEqual(list(jc.parsers.ping_s.parse(self.ubuntu_22_4_ping_ip_source_ip.splitlines(), quiet=True)), self.ubuntu_22_4_ping_ip_I_streaming_json)
+
+    def test_ping6_s_ip_I_ubuntu_22_4(self):
+        """
+        Test 'ping6 <ip> -I' on ubuntu 22.04
+        """
+        self.assertEqual(list(jc.parsers.ping_s.parse(self.ubuntu_22_4_ping6_ip_source_ip.splitlines(), quiet=True)), self.ubuntu_22_4_ping6_ip_I_streaming_json)
+
+    def test_ping6_s_hostname_I_ubuntu_22_4(self):
+        """
+        Test 'ping6 <hostname> -I' on ubuntu 22.04
+        """
+        self.assertEqual(list(jc.parsers.ping_s.parse(self.ubuntu_22_4_ping6_hostname_source_ip.splitlines(), quiet=True)), self.ubuntu_22_4_ping6_hostname_I_streaming_json)
+
+
     def test_ping_s_ip_O_fedora32(self):
         """
         Test 'ping <ip> -O' on fedora32
@@ -799,6 +869,12 @@ class MyTests(unittest.TestCase):
         """
         self.assertEqual(list(jc.parsers.ping_s.parse(self.pi_ping_ip_O_D.splitlines(), quiet=True)), self.pi_ping_ip_O_D_streaming_json)
 
+    def test_ping_s_missing_hostname(self):
+        """
+        Test 'ping' with missing hostname on linux
+        """
+        self.assertEqual(list(jc.parsers.ping_s.parse(self.centos_7_7_ping_missing_hostname.splitlines(), quiet=True)), self.centos_7_7_ping_missing_hostname_json)
+
 
 if __name__ == '__main__':
     unittest.main()
